@@ -17,6 +17,7 @@
 #include <cassert>
 #include <cstring>
 #include <cstdio>
+#include <cmath>
 
 #include <stdexcept>
 #include <string_view>
@@ -251,7 +252,7 @@ void AddToIntervalVector(std::vector<Interval> &vi, XYPOSITION left, XYPOSITION
 		vi.push_back(interval);
 	} else {
 		Interval &last = vi.back();
-		if (fabs(last.right-interval.left) < 0.01) {
+		if (std::abs(last.right-interval.left) < 0.01) {
 			// If new left is very close to previous right then extend last item
 			last.right = interval.right;
 		} else {
@@ -628,8 +629,8 @@ void SurfaceImpl::FillRectangle(PRectangle rc, ColourDesired back) {
 	if (gc) {
 		FillColour(back);
 		// Snap rectangle boundaries to nearest int
-		rc.left = lround(rc.left);
-		rc.right = lround(rc.right);
+		rc.left = std::round(rc.left);
+		rc.right = std::round(rc.right);
 		CGRect rect = PRectangleToCGRect(rc);
 		CGContextFillRect(gc, rect);
 	}
@@ -805,8 +806,8 @@ void Scintilla::SurfaceImpl::AlphaRectangle(PRectangle rc, int cornerSize, Colou
 		ColourDesired outline, int alphaOutline, int /*flags*/) {
 	if (gc) {
 		// Snap rectangle boundaries to nearest int
-		rc.left = lround(rc.left);
-		rc.right = lround(rc.right);
+		rc.left = std::round(rc.left);
+		rc.right = std::round(rc.right);
 		// Set the Fill color to match
 		CGContextSetRGBFillColor(gc, fill.GetRed() / 255.0, fill.GetGreen() / 255.0, fill.GetBlue() / 255.0, alphaFill / 255.0);
 		CGContextSetRGBStrokeColor(gc, outline.GetRed() / 255.0, outline.GetGreen() / 255.0, outline.GetBlue() / 255.0, alphaOutline / 255.0);
@@ -1115,7 +1116,7 @@ void SurfaceImpl::DrawTextTransparent(PRectangle rc, Font &font_, XYPOSITION yba
 	CGColorRef color = CGColorCreateGenericRGB(colour.GetRed()/255.0, colour.GetGreen()/255.0, colour.GetBlue()/255.0, 1.0);
 
 	QuartzTextStyle *style = TextStyleFromFont(font_);
-	style->setCTStyleColor(color);
+	style->setCTStyleColour(color);
 
 	CGColorRelease(color);
 
@@ -1232,7 +1233,7 @@ XYPOSITION SurfaceImpl::AverageCharWidth(Font &font_) {
 
 	XYPOSITION width = WidthText(font_, sizeString);
 
-	return round(width / strlen(sizeString));
+	return std::round(width / strlen(sizeString));
 }
 
 void SurfaceImpl::SetClip(PRectangle rc) {
@@ -1750,7 +1751,7 @@ void ListBoxImpl::SetFont(Font &font_) {
 	font.SetID(new QuartzTextStyle(*style));
 	NSFont *pfont = (__bridge NSFont *)style->getFontRef();
 	[colText.dataCell setFont: pfont];
-	CGFloat itemHeight = ceil(pfont.boundingRectForFont.size.height);
+	CGFloat itemHeight = std::ceil(pfont.boundingRectForFont.size.height);
 	table.rowHeight = itemHeight;
 }
 
