@@ -540,9 +540,14 @@ class TestSimple(unittest.TestCase):
 	def testGetSet(self):
 		self.ed.SetContents(b"abc")
 		self.assertEquals(self.ed.TextLength, 3)
-		result = ctypes.create_string_buffer(b"\0" * 5)
+		# String buffer containing exactly 5 digits
+		result = ctypes.create_string_buffer(b"12345", 5)
+		self.assertEquals(result.raw, b"12345")
 		length = self.ed.GetText(4, result)
+		self.assertEquals(length, 3)
 		self.assertEquals(result.value, b"abc")
+		# GetText has written the 3 bytes of text and a terminating NUL but left the final digit 5
+		self.assertEquals(result.raw, b"abc\x005")
 
 	def testAppend(self):
 		self.ed.SetContents(b"abc")
@@ -1634,6 +1639,16 @@ class TestStyleAttributes(unittest.TestCase):
 		self.ed.StyleSetHotSpot(self.ed.STYLE_DEFAULT, 1)
 		self.assertEquals(self.ed.StyleGetHotSpot(self.ed.STYLE_DEFAULT), 1)
 
+	def testFoldDisplayTextStyle(self):
+		self.assertEquals(self.ed.FoldDisplayTextGetStyle(), 0)
+		self.ed.FoldDisplayTextSetStyle(self.ed.SC_FOLDDISPLAYTEXT_BOXED)
+		self.assertEquals(self.ed.FoldDisplayTextGetStyle(), self.ed.SC_FOLDDISPLAYTEXT_BOXED)
+
+	def testDefaultFoldDisplayText(self):
+		self.assertEquals(self.ed.GetDefaultFoldDisplayText(), b"")
+		self.ed.SetDefaultFoldDisplayText(0, b"...")
+		self.assertEquals(self.ed.GetDefaultFoldDisplayText(), b"...")
+
 class TestIndices(unittest.TestCase):
 	def setUp(self):
 		self.xite = Xite.xiteFrame
@@ -2282,6 +2297,11 @@ class TestWordChars(unittest.TestCase):
 		data = self.ed.GetPunctuationChars(None)
 		self.assertCharSetsEqual(data, expected)
 
+	def testCharacterCategoryOptimization(self):
+		self.assertEquals(self.ed.CharacterCategoryOptimization, 0x100)
+		self.ed.CharacterCategoryOptimization = 0x1000
+		self.assertEquals(self.ed.CharacterCategoryOptimization, 0x1000)
+
 class TestExplicitTabStops(unittest.TestCase):
 
 	def setUp(self):
